@@ -18,6 +18,7 @@
 # Authors: Quinn Storm (quinn@beryl-project.org)
 #          Patrick Niklaus (marex@opencompositing.org)
 #          Guillaume Seguin (guillaume@segu.in)
+#          Christopher Williams (christopherw@verizon.net)
 # Copyright (C) 2007 Quinn Storm
 
 import pygtk
@@ -65,8 +66,10 @@ ImageStock    = 4
 #
 FilterName = 1 << 0
 FilterLongDesc = 1 << 1
-FilterValue = 1 << 2
-FilterAll = FilterName | FilterLongDesc | FilterValue
+FilterValue = 1 << 2    # Settings Only
+FilterCategory = 1 << 3 # Plugins Only
+FilterAll = FilterName | FilterLongDesc | FilterValue | FilterCategory
+
 # Paths
 #
 DataDir = "/usr/local/share"
@@ -79,7 +82,7 @@ Tooltips = gtk.Tooltips()
 
 # Version
 #
-Version = "0.7.4"
+Version = "0.7.6"
 
 
 # Translation
